package radioai

import (
	"os"
	"os/exec"
)

type IcecastController struct {
	PublicIp   string
	ConfigFile string
	InitScript string
	config     *icecastConfig
}

func NewIcecastController(publicIp string) *IcecastController {
	return &IcecastController{
		PublicIp:   publicIp,
		ConfigFile: "/etc/icecast2/icecast.conf",
		InitScript: "/etc/init.d/icecast2",
		config:     newIcecastConfig(publicIp),
	}
}

func (ic *IcecastController) reload() error {
	err := exec.Command(ic.InitScript, "reload").Run()
	if err != nil {
		err = exec.Command(ic.InitScript, "start").Run()
	}
	return err
}

func (ic *IcecastController) Update(conf *ClusterConfig, isMaster bool, masterAddr string) error {
	tmpf := ic.ConfigFile + ".tmp"
	defer os.Remove(tmpf)

	ic.config.Update(conf, isMaster, masterAddr)
	if err := ic.config.EncodeToFile(tmpf); err != nil {
		return err
	}

	if err := os.Rename(tmpf, ic.ConfigFile); err != nil {
		return err
	}

	return ic.reload()
}
